<!DOCTYPE html>

  <html lang="en-us" dir="ltr">
  <head>
    <title>Login</title>
    <link rel="stylesheet" type="text/css" href="/static/admin/css/base.css">
    <link rel="stylesheet" type="text/css" href="/static/admin/css/nav_sidebar.css">
    <script src="/static/admin/js/nav_sidebar.js" defer></script>
    <link rel="stylesheet" type="text/css" href="/static/admin/css/login.css">

    <style>
    :root {
        --primary: #315d26;
        --secondary: #435d26;
        --button-hover-bg: #80b660;
    }
    </style>

    <meta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1.0, maximum-scale=1.0">
    <link rel="stylesheet" type="text/css" href="/static/admin/css/responsive.css">
    <meta name="robots" content="NONE,NOARCHIVE">
  </head>


  <body style="background-color: lavenderblush;" class=" login" data-admin-utc-offset="18000">
  <!-- Container -->
    <div id="container">       
      <!-- Header -->
      <div id="header">
        <div id="branding">
          <h1 style="color: white;" id="site-name">Login</h1>
        </div>
      </div>
        <!-- END Header -->

      <div class="main shifted" id="main">
        <div class="content">
          <!-- Content -->
          <div id="content" class="colM">
            <div id="content-main">
              <form action="" method="post" id="login-form">
                {% csrf_token %}
                <div class="form-row">
                  <label class="required" for="id_username">Username:</label> <input type="text" name="username" autofocus autocapitalize="none" autocomplete="username" maxlength="150" required id="id_username">
                </div>
                <div class="form-row">
                  
                  <label class="required" for="id_password">Password:</label> <input type="password" name="password" autocomplete="current-password" required id="id_password">
                </div>
                <div class="submit-row">
                  <input type="submit" value="Log in">
                </div>
              </form>
            </div>

            <br class="clear">
          </div>
        <!-- END Content -->
        <div id="footer"></div>
          </div>
        </div>
    </div>
  <!-- END Container -->
  </body>
</html>
