
.summary {
    background-color: gray;
    color: white;
    /* margin-top: 5%; */
    padding: 2%;
    /* margin-bottom: 5%; */
}

.summary-data {
    text-align: left;
    background-color: lightgray;
    color: black;
    border-radius: 0.2rem;
}

.summary-table {
    width: 100%;
    font-size: large;
}

.summary-table-left-pad {
    padding-left: 5%;
}