# Generated by Django 3.2.13 on 2022-11-17 09:49

from django.db import migrations
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('explorer', '0003_userrole'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Option',
            new_name='Action',
        ),
        migrations.AlterModelManagers(
            name='action',
            managers=[
                ('actions', django.db.models.manager.Manager()),
            ],
        ),
    ]
