{% extends 'explorer/base.html' %}


{% block title %}
    Logout
{% endblock title %}

{% block navbar %}

{% endblock navbar %}

{% block content %}
    <!-- MESSAGE AREA -->
    <div class="jumbotron text-center bg-success text-white">
        <h1>Logout Successful</h1>
        <br>
        <br>
        <a  class="btn btn-warning" href="{% url 'explorer-login' %}?next={% url 'explorer-main' %}">Login Again</a>
    </div>
{% endblock content %}