# Generated by Django 3.2.13 on 2023-01-02 07:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('explorer', '0004_auto_20221117_1449'),
    ]

    operations = [
        migrations.RenameField(
            model_name='userrole',
            old_name='opertations',
            new_name='actions',
        ),
    ]
