# Generated by Django 3.2.13 on 2022-10-30 16:00

from django.db import migrations, models
import django.db.models.manager
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('explorer', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Option',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=120)),
                ('creation_date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            managers=[
                ('options', django.db.models.manager.Manager()),
            ],
        ),
    ]
